#!/bin/sh

# This script is supposed to install CGP that allows viewing graphs in nice canvas in you web browser

# COLORS
NOCOLOR='\e[0m'         # Color Reset
RED='\e[0;31m'          # Red
GREEN='\e[0;32m'        # Green


BASE=/usr/local/monitoring/collectd

# Extract CGP to web server root folder
echo -e "$GREEN extracting CGP... $NOCOLOR"
mkdir -p $BASE
cd $BASE
if [ -f "$BASE/collectd_web.tar.gz" ]; then
    echo -e "$GREEN Extracting collectd_web.tar.gz $NOCOLOR"
    tar -xzf $BASE/collectd_web.tar.gz
else
    echo -e "$RED No collectd Web was extracted. No CGP thus :( $NOCOLOR"
fi
if [ -d "$BASE/web/CGP" ]; then
   if [ -d "/var/www/html/CGP" ]; then 
        rm -fr /var/www/html/CGP
        echo -e "$RED We shall overwrite the original /var/www/html/CGP ... $NOCOLOR"
    fi
    # Handle Gentoo and Centos web folder
    if [ -d /var/www/html/ ] && [ -n "$(ls /etc/redhat-release 2>/dev/null)" ]; then 
        echo yes | cp -R $BASE/web/CGP /var/www/html/
        chown root:root /var/www/html/CGP
    fi
    if [ -d /home/sdfrance/www ] && [ -n "$(ls /etc/gentoo-release 2>/dev/null)" ]; then 
        echo yes | cp -R $BASE/web/CGP /home/sdfrance/www/cgp
        chown sdfrance:users /home/sdfrance/www/cgp
    fi
    rm -fr $BASE/web/CGP 
else
    echo -e "$RED Folder: $BASE/web/CGP DOES NOT EXIST. NOT COPYING TO: Web folder $NOCOLOR"
fi

# Enable Virtual Host for CGP
if [ -f "$BASE/web/CGP_LAMP_vhost.conf" ]; then
    mkdir -p /etc/httpd/conf/vhosts.d/
    vhost_exist=$(cat $BASE/web/CGP_LAMP_vhost.conf 2>/dev/null | grep cgp | grep -v '#')
    if  [ -z "${vhost_exist}" ]; then 
        cat $BASE/web/CGP_LAMP_vhost.conf >> /etc/httpd/conf/vhosts.d/00_default_vhost.conf
    fi
else
    echo -e "$RED $BASE/web/CGP_LAMP_vhost.conf  DOES NOT EXIST $NOCOLOR"
fi

# We no more need the web folder
if [ -d "$BASE/web" ]; then
    rm -rf $BASE/web 2>/dev/null
fi

# Symlinking the CGP folder in /home/sdfrance/www
if [ -d "/var/www/html/CGP" ] && [ -n "$(ls /etc/redhat-release 2>/dev/null)" ]; then
    mkdir -p /home/sdfrance/www/
    ln -s  /var/www/html/CGP/ /home/sdfrance/www/cgp
else
    echo -e "$RED Folder /var/www/html/CGP/ DOES NOT EXIST $NOCOLOR"
fi

# Generating a random password for CGP access
password=`pwgen -cs1 10`
htpasswd -bmc $BASE/etc/collectd-htpasswd cgp "$password"
echo "$password" > /root/.cgp
service httpd reload
/etc/init.d/httpd reload # Sometimes service command in unavailable
